cuda: fix warnings for unused variable/function (llama/26688)
This commit is contained in:
parent
5693378610
commit
79ab70c922
|
|
@ -5209,6 +5209,7 @@ static bool ggml_backend_cuda_device_offload_op(ggml_backend_dev_t dev, const gg
|
||||||
|
|
||||||
static ggml_backend_event_t ggml_backend_cuda_device_event_new(ggml_backend_dev_t dev) {
|
static ggml_backend_event_t ggml_backend_cuda_device_event_new(ggml_backend_dev_t dev) {
|
||||||
#ifdef GGML_CUDA_NO_PEER_COPY
|
#ifdef GGML_CUDA_NO_PEER_COPY
|
||||||
|
GGML_UNUSED(dev);
|
||||||
return nullptr;
|
return nullptr;
|
||||||
#else
|
#else
|
||||||
ggml_backend_cuda_device_context * dev_ctx = (ggml_backend_cuda_device_context *)dev->context;
|
ggml_backend_cuda_device_context * dev_ctx = (ggml_backend_cuda_device_context *)dev->context;
|
||||||
|
|
|
||||||
|
|
@ -8,7 +8,6 @@ struct __builtin_align__(32) float8 {
|
||||||
float x; float y; float z; float w;
|
float x; float y; float z; float w;
|
||||||
float p; float q; float r; float s;
|
float p; float q; float r; float s;
|
||||||
};
|
};
|
||||||
#endif
|
|
||||||
|
|
||||||
#if CUDART_VERSION >= 12080
|
#if CUDART_VERSION >= 12080
|
||||||
static __device__ __forceinline__ float nvfp4_native_scale_error(
|
static __device__ __forceinline__ float nvfp4_native_scale_error(
|
||||||
|
|
@ -49,6 +48,7 @@ static __device__ __forceinline__ float nvfp4_native_scale_error(
|
||||||
return err;
|
return err;
|
||||||
}
|
}
|
||||||
#endif // CUDART_VERSION >= 12080
|
#endif // CUDART_VERSION >= 12080
|
||||||
|
#endif // defined(BLACKWELL_MMA_AVAILABLE)
|
||||||
|
|
||||||
__launch_bounds__(CUDA_QUANTIZE_BLOCK_SIZE, 1)
|
__launch_bounds__(CUDA_QUANTIZE_BLOCK_SIZE, 1)
|
||||||
static __global__ void quantize_q8_1(
|
static __global__ void quantize_q8_1(
|
||||||
|
|
|
||||||
Loading…
Reference in New Issue